@@ -7,4 +7,4 @@ from .SDR.SDR import cal_sdr
 from .STI.cal_sti import cal_sti
 from .STOI.STOI import *
 from .resample.resampler import resample
-from main import compute_audio_quality
\ No newline at end of file
+from .main import compute_audio_quality
\ No newline at end of file
